@@ -31,7 +31,8 @@ class CardBase:
                                       'card_body_css_class': 'card-body cards-list'}},
                  'list_selection': {'name': 'cards/standard/list_selection.html',
                                     'context': {'card_css_class': 'card django-card',
-                                                'card_body_css_class': 'card-body cards-list'}},
+                                                'card_body_css_class': 'card-body cards-list',
+                                                'card_link_css_class': 'list-group-item cards-list-group-item'}},
                  'tree_selection': {'name': 'cards/standard/tree_selection.html',
                                     'context': {'card_css_class': 'card django-card',
                                                 'card_body_css_class': 'card-body cards-list'}},
