@@ -1,3 +1,6 @@
+import json
+
+from ajax_helpers.utils import is_ajax
 from django.http import HttpResponse
 from django.template.loader import render_to_string
 
@@ -20,12 +23,8 @@ class CardMixin:
 
             field_setup_table_field = f'setup_table_{table_id}'
             if hasattr(self, field_setup_table_field):
-                self.setup_cards()
-                card = self.cards[table_id]
-                card.current_card = table_id
-                card.process_data()
-                table = card.tables[request.POST['table_id']]
-
+                self.setup_datatable_cards()
+                table = self.tables[table_id]
                 field_query = f'get_{table_id}_query'
                 if hasattr(self, field_query):
                     results = getattr(self, field_query)(table, **kwargs)
@@ -34,7 +33,13 @@ class CardMixin:
                 table_data = table.get_json(request, results)
                 return HttpResponse(table_data, content_type='application/json')
         # noinspection PyUnresolvedReferences
-        return super().post(request, *args, **kwargs)
+        if hasattr(super(), 'post'):
+            # noinspection PyUnresolvedReferences
+            return super().post(request, *args, **kwargs)
+        elif is_ajax(request) and request.content_type == 'application/json':
+            response = json.loads(request.body)
+            raise Exception(f'May need to use AjaxHelpers Mixin or'
+                            f' add one of these \n{", ".join(response.keys())}\nto ajax_commands ')
 
     def add_card_group(self, *args, div_css_class):
         cards = [self.cards[card] for card in args]
@@ -58,6 +63,7 @@ class CardMixin:
         return self.cards[card_name]
 
     def get_context_data(self, **kwargs):
+        self.setup_datatable_cards()
         self.setup_cards()
         super_context = getattr(super(), 'get_context_data')
         if super_context and callable(super_context):
@@ -73,8 +79,25 @@ class CardMixin:
         return render_to_string('cards/groups/groups.html', context={'groups': self.card_groups})
 
     def setup_cards(self):
-        return
+        if hasattr(super(), 'setup_cards'):
+            super().setup_cards()
+
+    def setup_datatable_cards(self):
+        if hasattr(super(), 'setup_datatable_cards'):
+            super().setup_datatable_cards()
 
     def add_html_card(self, card_name, context_template_name, context, **kwargs):
         html = render_to_string(context_template_name, context)
         return self.add_card(card_name=card_name, group_type=CARD_TYPE_HTML, html=html, **kwargs)
+
+    def row_edit(self, **kwargs):
+        row_data = json.loads(kwargs.pop('row_data'))
+        self.setup_datatable_cards()
+        table_id = kwargs['table_id']
+        table = self.tables[table_id]
+        row_object = table.model.objects.get(pk=kwargs['row_no'][1:])
+        field_setup_table_field = f'setup_table_{table_id}'
+        if hasattr(self, field_setup_table_field):
+            getattr(self, field_setup_table_field)(table=table, details_object=self.cards[table_id].details_object)
+        table.columns[kwargs['changed'][0]].alter_object(row_object, row_data[kwargs['changed'][0]])
+        return table.refresh_row(self.request, kwargs['row_no'])
\ No newline at end of file
